@@ -37,10 +37,13 @@ locperc <- function( vals, stds, percentiles = c( 0.5, 1, 2, 5, 95 ),
 # get z-scores and remove blind spot
   zscore <- vals[,locini:( locini + settings$locnum - 1 )]
   stdloc <- t( matrix( rep( stds, nrow( vals ) ), nrow = settings$locnum, ncol = nrow( vals ) ) )
-  zscore <- zscore[,-settings$bs]
-  stdloc <- stdloc[,-settings$bs]
+  if( all( !is.na( settings$bs ) ) ) {
+    zscore <- zscore[,-settings$bs]
+    stdloc <- stdloc[,-settings$bs]
+  }
   zscore <- zscore / stdloc
-  stds2  <- stds[-settings$bs]
+  stds2  <- stds
+  if( all( !is.na( settings$bs ) ) ) stds2  <- stds2[-settings$bs]
 
 # create the data frame to return
   locper  <- NULL
@@ -58,7 +61,8 @@ locperc <- function( vals, stds, percentiles = c( 0.5, 1, 2, 5, 95 ),
     eval( parse( text = texteval ) )
   }
   locper  <- as.data.frame( locper )
-  locper2 <- locper[-settings$bs,]
+  locper2 <- locper
+  if( all( !is.na( settings$bs ) ) ) locper2 <- locper2[-settings$bs,]
   idx     <- attr( locper2, "row.names" )
 
 # pool locations?
@@ -69,16 +73,18 @@ locperc <- function( vals, stds, percentiles = c( 0.5, 1, 2, 5, 95 ),
                      stds2[i]
     }
   } else {
+    lenbs <- 0
+    if( all( !is.na( settings$bs ) ) ) lenbs <- length( settings$bs )
     locper2 <- t( matrix( rep( wtd.quantile( c( as.matrix( zscore ) ), probs = percentiles / 100, type = type,
-                                             weights = rep( idweight, settings$locnum - length( settings$bs ) ),
+                                             weights = rep( idweight, settings$locnum - lenbs ),
                                              normwt = TRUE ),
-                               settings$locnum - length( settings$bs ) ),
-                  ncol = settings$locnum - length( settings$bs ), nrow = length( percentiles ) ) ) *
+                               settings$locnum - lenbs ),
+                  ncol = settings$locnum - lenbs, nrow = length( percentiles ) ) ) *
                stds2
   }
 
-  locper[idx,]         <- locper2
-  locper[settings$bs,] <- NA
+  locper[idx,] <- locper2
+  if( all( !is.na( settings$bs ) ) ) locper[settings$bs,] <- NA
   
   return( locper )
 }
